{% extends "helpdesk/base.html" %}{% load i18n %}
{% block helpdesk_title %}{% trans "Edit followup" %}{% endblock %}
{% block helpdesk_head %}{% endblock helpdesk_head %}

{% block helpdesk_body %}

{% include "helpdesk/ticket_desc_table.html" %}

<h3>{% trans "Edit FollowUp" %}</h3>
    <form action="." method="POST" name="edit_followup_form">
        {{ form.non_field_errors }}
        <fieldset>
        <dl>
            <dt><label for='id_ticket'>{% trans "Reassign ticket:" %}</label></dt>
            <dd>{{ form.ticket }}</dd>
            <dt><label for="id_title">{% trans "Title:" %}</label></dt>
            <dd>{{ form.title }}</dd>
            <dt><label for="id_comment">{% trans "Comment:" %}</label></dt>
            <dd>{{ form.comment }}</dd>
            <dt><label for="id_public">Public:</label></dt>
            <dd>{{ form.public }}</dd>
                <p>Public tickets are viewable by the submitter and all staff, but non-public tickets can only be seen by staff.</p>
            <dt><label for="id_new_status">New Status:</label></dt>
            <dd>{{ form.new_status }}</dd>
                <p>If the status was changed, what was it changed to?</p>
        </dl>
        </fieldset>
        <p><input type="submit" value="Submit"></p>{% csrf_token %}
    </form>
{% endblock helpdesk_body %}