{% extends "helpdesk/public_base.html" %}{% load i18n %}
{% block helpdesk_title %}{% trans "Logged Out" %}{% endblock %}

{% block helpdesk_body %}{% blocktrans %}
<h2>Logged Out</h2>

<p>Thanks for being here. Hopefully you've helped resolve a few tickets and make the world a better place.</p>

{% endblocktrans %}{% endblock %}
