body {
    font: 10pt "Trebuchet MS", Arial, sans-serif;
    background-color: #fff;
    text-align: center;
}

table {
    border-collapse: collapse;
    margin-top: 8px;
    padding: 80px;
}

#container {
    width: 700px;
    margin: 0 auto;
    text-align: left;
}

#header h1 {
    float: left;
    margin-top: 20px;
    padding-top: 20px;
    line-height: 24px;
}

#header ul {
    float: right;
    margin-top: 40px;
    line-height: 24px;
}
#header li {
    display: inline;
    float: left;
}

#header li a {
    padding: 2px 3px;
    margin: 2px;
    border: solid #444 1px;
    color: #000;
    background-color: #eee;
    text-decoration: none;
    font-size: 10pt;
    line-height: 12pt;
}

#searchform .input {
    border: solid #444 1px;
    background-color: #fff;
    color: #ccc;
    padding: 0px 3px;
    margin: 0px 2px;
    font-size: 10pt;
    line-height: 12pt;
}

#searchform .input:focus {
    color: #000;
}

#header li a:hover {
    background-color: #ccc;
}

#header, #body, #footer {
    clear: both;
}

label {
    font-weight: bold;
}

span.form_optional {
    color: #666;
    font-size: 95%;
}

dd.form_help_text {
    color: #666;
    font-size: 95%;
}

ul.errorlist {
    color: #a33;
    font-size: 95%;
}

dt {
    padding-top: 8px;
}

.row_tablehead {
    background-color: #6593C0;
    font-weight: bold;
    color: #fff;
    border-bottom: solid white 1px;
}

.row_tablehead span.ticket_toolbar {
    float: right;
    text-align: right;
}

.row_tablehead td {
    padding-left: 12px;
    line-height: 16pt;
    font-size: 12pt;
}

.row_columnheads {
    background-color: #94C0E8;
    font-size: 10pt;
    line-height: 12pt;
}

th {
    font-weight: bold;
    color: #3E5F84;
    text-align: left;
    padding-left: 12px;
}

.row_odd {
    background-color: #fff;
}

.row_even {
    background-color: #ecf6fc;
}

.row_odd, .row_even {
    color: #6C79A0;
    border-bottom: solid #d5e7fd 1px;
}

.row_odd th, .row_even th {
    font-size: 10pt;
}

.row_odd td:first-child, .row_even td:first-child {
    padding-left: 12px;
}

.cell_bold {
    font-weight: bold;
}

td a, th a {
    color: inherit;
    text-decoration: none;
}

td {
    font-size: 10pt;
}

td.report {
    font-size: 10pt;
    text-align: center;
}

.hover {
    background-color: #bcd4ec;
}

div.followup {
    width: 100%;
    border-top: solid #666 1px;
    padding:0 0 2px;
}

div.followup_mod {
    width: auto;
    border: solid #666 1px;
    padding: 5px;
    margin: 0px 0px 10px;
}

div.followup .title, div.followup_mod .title {
    font-weight: bold;
    font-size: 10pt;
}

div.followup .title span, div.followup_mod .title span {
    color: #aaa;
    font-weight: normal;
}

div.followup_mod small {
    float: right;
    font-weight: bold;
    font-style: italic;
}

span.private {
    color: #aaa;
    font-style: italic;
}

a.ticket_link_status_Closed {
    text-decoration: line-through;
}

a.ticket_link_status_Open {
    color: #393;
}

a.ticket_link_status_Reopened {
    color: #393;
}

a.ticket_link_status_Resolved {
    color: #996;
}

a.ticket_link_status {
    color: #369;
    font: 12pt Garamond;
}

a img {
    border: none;
    padding: 2px;
}

textarea#commentBox {
    width: 100%;
}

.filterBox {
    display: none;
    float: left;
    border: solid #ccc 1px;
    padding: 2px;
    margin: 4px;
    max-width: 24%;
}

.filterBoxShow {
    display: block;
}

.filterBox label {
    clear: both;
    display: block;
}

.filterBox .filterHelp {
    color: #aaa;
    font-size: 0.8em;
    clear: both;
}

span.priority1, span.priority2, span.priority3, span.priority4, span.priority5 {
    padding: 1px 12px;
    font-weight: bold;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    margin: 2px;
    display: block;
    text-align: center;
    width: 20px;
}

span.priority1 {
    background-color: #c00;
    color: #fff;
}

span.priority2 {
    background-color: #e80;
    color: #fff;
}

span.priority3 {
    background-color: #fe8;
    color: #000;
}

span.priority4 {
    background-color: #59c;
    color: #fff;
}

span.priority5 {
    background-color: #8c5;
    color: #fff;
}

a.followup-edit {
    float:right;
}

/* tooltips for link hover */
a.tooltip, a.tooltip:link, a.tooltip:visited, a.tooltip:active  {
  position: relative;
  text-decoration: none;
  font-style: italic;
}

a.tooltip:hover {
  background: transparent;
}

a.tooltip span {
  display: none;
  text-decoration: none;
}

a.tooltip:hover span {
  display: block;
  position: absolute;
  top: 25px;
  left: 0;
  width: 250px;
  z-index: 10;
  color: #000000;
  border:1px solid #000000;
  background: #FFFFCC;
  font: 12px Verdana, sans-serif;
  text-align: left;
}

